@@ -31,31 +31,20 @@
 #define BROWSER_PLACE			"/apps/liferea/browser_place"
 #define BROWSER_COMMAND			"/apps/liferea/browser"
 
-#define GNOME_DEFAULT_BROWSER_COMMAND	"gnome-open '%s'"
-#define DEFAULT_BROWSER_COMMAND		"mozilla '%s'"
-
 #define DEFAULT_FONT			"/desktop/gnome/interface/document_font_name"
 #define USER_FONT			"/apps/liferea/browser-font"
-#define REFOCUS_TIMEOUT			"/apps/liferea/refocus-timeout"
 #define DISABLE_JAVASCRIPT		"/apps/liferea/disable-javascript"
 #define SOCIAL_BM_SITE			"/apps/liferea/social-bm-site"
-#define SOCIAL_BM_HIDE			"/apps/liferea/social-bm-hide"
-#define SOCIAL_LINK_SEARCH_SITE		"/apps/liferea/social-link-search-site"
-#define SOCIAL_LINK_SEARCH_HIDE		"/apps/liferea/social-link-search-hide"
 #define ENABLE_PLUGINS			"/apps/liferea/enable-plugins"
 
 /* enclosure handling */
 #define ENCLOSURE_DOWNLOAD_TOOL		"/apps/liferea/enclosure-download-tool"
 #define ENCLOSURE_DOWNLOAD_PATH		"/apps/liferea/enclosure-download-path"
 
-/* item list settings */
-#define DATE_FORMAT			"/apps/liferea/date-format"
-
 /* feed handling settings */
 #define DEFAULT_MAX_ITEMS		"/apps/liferea/maxitemcount"
 #define DEFAULT_UPDATE_INTERVAL		"/apps/liferea/default-update-interval"
 #define STARTUP_FEED_ACTION		"/apps/liferea/startup_feed_action"
-#define ENABLE_FETCH_RETRIES		"/apps/liferea/enable-fetch-retries"
 
 /* folder handling settings */
 #define FOLDER_DISPLAY_MODE		"/apps/liferea/folder-display-mode"
@@ -68,7 +57,6 @@
 #define DONT_MINIMIZE_TO_TRAY		"/apps/liferea/dont-minimize-to-tray"
 #define START_IN_TRAY			"/apps/liferea/start-in-tray"
 #define SHOW_POPUP_WINDOWS		"/apps/liferea/show-popup-windows"
-#define POPUP_PLACEMENT			"/apps/liferea/popup-placement"
 #define DISABLE_TOOLBAR			"/apps/liferea/disable-toolbar"
 #define TOOLBAR_STYLE			"/apps/liferea/toolbar-style"
 #define LAST_WINDOW_X			"/apps/liferea/last-window-x"
@@ -82,7 +70,6 @@
 #define LAST_ZOOMLEVEL			"/apps/liferea/last-zoomlevel"
 
 /* networking settings */
-#define NETWORK_TIMEOUT			"/apps/liferea/network-timeout"
 #define PROXY_DETECT_MODE		"/apps/liferea/proxy/detect-mode"
 #define PROXY_HOST			"/apps/liferea/proxy/host"
 #define PROXY_PORT			"/apps/liferea/proxy/port"
@@ -98,7 +85,6 @@
 #define GNOME_PROXY_PASSWD		"/system/http_proxy/authentication_password"
 
 /* other settings */
-#define DISABLE_DBUS			"/apps/liferea/disable-dbus"
 #define SYNC_AVAHI_ENABLED		"/apps/liferea/sync/use_avahi"
 #define SYNC_AVAHI_SERVICE_NAME		"/apps/liferea/sync/avahi_service_name"
 #define SYNC_AVAHI_PASSWORD		"/apps/liferea/sync/avahi_password"
@@ -106,7 +92,6 @@
 /* initializing methods */
 void	conf_init (void);
 void	conf_deinit (void);
-void	conf_load (void);
 
 /* preferences access methods */
 
@@ -114,28 +99,32 @@ void	conf_load (void);
  * Retrieves the value of the given boolean configuration key.
  *
  * @param key	the configuration key
+ * @param value the value, if the function returned FALSE it's always FALSE
  *
- * @returns boolean value (FALSE on failure)
+ * @returns TRUE if the configuration key was found
  */
-gboolean conf_get_bool_value (const gchar *key);
+gboolean conf_get_bool_value (const gchar *key, gboolean *value);
 
 /**
  * Retrieves the value of the given string configuration key.
+ * The string has to be freed by the caller.
  *
  * @param key	the configuration key
+ * @param value the value, if the function returned FALSE an empty string
  *
- * @returns string value (NULL on failure, to be free'd using g_free)
+ * @returns TRUE if the configuration key was found
  */
-gchar *	conf_get_str_value (const gchar *key);
+gboolean conf_get_str_value (const gchar *key, gchar **value);
 
 /**
  * Retrieves the value of the given integer configuration key.
  *
  * @param key	the configuration key
+ * @param value the value, if the function returned FALSE it's always 0
  *
- * @returns integer value (0 on failure)
+ * @returns TRUE if the configuration key was found
  */
-gint conf_get_int_value (const gchar *key);
+gboolean conf_get_int_value (const gchar *key, gint *value);
 
 /**
  * Sets the value of the given boolean configuration key.
