@@ -47,11 +47,11 @@ debug_get_prefix (unsigned long flag)
 	if (flag & DEBUG_PARSING)	return "PARSING";
 	if (flag & DEBUG_GUI)		return "GUI";
 	if (flag & DEBUG_HTML)		return "HTML";
-	if (flag & DEBUG_PLUGINS)	return "PLUGINS";
 	if (flag & DEBUG_TRACE)		return "TRACE";
 	if (flag & DEBUG_NET)		return "NET";
 	if (flag & DEBUG_DB)		return "DB";
 	if (flag & DEBUG_PERF)		return "PERF";
+	if (flag & DEBUG_VFOLDER)	return "VFOLDER";
 	return "";	
 }
 
