@@ -1,7 +1,7 @@
 /**
  * @file itemset.c handling sets of items
  * 
- * Copyright (C) 2005-2008 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2005-2011 Lars Lindner <lars.lindner@gmail.com>
  * Copyright (C) 2005-2006 Nathan J. Conrad <t98502@users.sourceforge.net>
  *
  * This program is free software; you can redistribute it and/or modify
@@ -21,7 +21,6 @@
 
 #include <string.h>
 
-#include "conf.h"
 #include "common.h"
 #include "db.h"
 #include "debug.h"
@@ -31,6 +30,9 @@
 #include "itemset.h"
 #include "metadata.h"
 #include "node.h"
+#include "rule.h"
+#include "vfolder.h"
+#include "fl_sources/node_source.h"
 
 void
 itemset_foreach (itemSetPtr itemSet, itemActionFunc callback)
@@ -67,18 +69,20 @@ itemset_get_max_item_count (itemSetPtr itemSet)
  * @param maxChecks     maximum number of item checks
  * @param allowUpdates	TRUE if item content update is to be
  *      		allowed for existing items
+ * @param allowStateChanges	TRUE if item state shall be
+ *				overwritten by source
  *
  * @returns TRUE if merging instead of updating is necessary) 
  */
 static gboolean
-itemset_generic_merge_check (GList *items, itemPtr newItem, gint maxChecks, gboolean allowUpdates)
+itemset_generic_merge_check (GList *items, itemPtr newItem, gint maxChecks, gboolean allowUpdates, gboolean allowStateChanges)
 {
 	GList		*oldItemIdIter = items;
 	itemPtr		oldItem = NULL;
 	gboolean	found, equal = FALSE;
 
 	/* determine if we should add it... */
-	debug1 (DEBUG_CACHE, "check new item for merging: \"%s\"", item_get_title (newItem));
+	debug3 (DEBUG_CACHE, "check new item for merging: \"%s\", %i, %i", item_get_title (newItem), allowUpdates, allowStateChanges);
 		
 	/* compare to every existing item in this feed */
 	found = FALSE;
@@ -111,6 +115,12 @@ itemset_generic_merge_check (GList *items, itemPtr newItem, gint maxChecks, gboo
 		if (item_get_id (oldItem)) {			
 			if (0 == strcmp (item_get_id (oldItem), item_get_id (newItem))) {
 				found = TRUE;
+
+				/* found corresponding item, check if they are REALLY equal (eg, read status may have changed) */
+				if(oldItem->readStatus != newItem->readStatus) 
+					equal = FALSE;
+				if(oldItem->flagStatus != newItem->flagStatus)
+					equal = FALSE;
 				break;
 			} else {
 				/* different ids, but the content might be still equal (e.g. empty)
@@ -153,6 +163,15 @@ itemset_generic_merge_check (GList *items, itemPtr newItem, gint maxChecks, gboo
 				metadata_list_free (oldItem->metadata);
 				oldItem->metadata = newItem->metadata;
 				newItem->metadata = NULL;
+
+				/* Only update item state for feed sources where it is necessary
+				   which means online accounts we sync against, but not normal
+				   online feeds where items have no read status. */
+				if (allowStateChanges) {
+					oldItem->readStatus = newItem->readStatus;
+					oldItem->flagStatus = newItem->flagStatus;
+				}
+				
 				db_item_update (oldItem);
 				debug0 (DEBUG_CACHE, "-> item already existing and was updated");
 			} else {
@@ -169,17 +188,22 @@ itemset_generic_merge_check (GList *items, itemPtr newItem, gint maxChecks, gboo
 static gboolean
 itemset_merge_item (itemSetPtr itemSet, GList *items, itemPtr item, gint maxChecks, gboolean allowUpdates)
 {
+	gboolean	allowStateChanges = FALSE;
 	gboolean	merge;
 	nodePtr		node;
 
 	debug2 (DEBUG_UPDATE, "trying to merge \"%s\" to node id \"%s\"", item_get_title (item), itemSet->nodeId);
+
+	g_assert (itemSet->nodeId);
+	node = node_from_id (itemSet->nodeId);
+	if (node)
+		allowStateChanges = NODE_SOURCE_TYPE (node)->capabilities & NODE_SOURCE_CAPABILITY_ITEM_STATE_SYNC;
 	
 	/* first try to merge with existing item */
-	merge = itemset_generic_merge_check (items, item, maxChecks, allowUpdates);
+	merge = itemset_generic_merge_check (items, item, maxChecks, allowUpdates, allowStateChanges);
 
 	/* if it is a new item add it to the item set */	
 	if (merge) {
-		g_assert (itemSet->nodeId);
 		g_assert (!item->nodeId);
 		g_assert (!item->id);
 		item->nodeId = g_strdup (itemSet->nodeId);
@@ -213,7 +237,6 @@ itemset_merge_item (itemSetPtr itemSet, GList *items, itemPtr item, gint maxChec
 		}
 
 		/* step 4: Check item for new enclosures to download */
-		node = node_from_id (itemSet->nodeId);
 		if (node && (((feedPtr)node->data)->encAutoDownload)) {
 			GSList *iter = metadata_list_get_values (item->metadata, "enclosure");
 			while (iter) {
@@ -352,12 +375,15 @@ itemset_merge_items (itemSetPtr itemSet, GList *list, gboolean allowUpdates, gbo
 			item->readStatus = TRUE;
 			
 		if (itemset_merge_item (itemSet, items, item, length, allowUpdates)) {
+			vfolder_foreach_data (vfolder_merge_item, item);
 			newCount++;
 			items = g_list_prepend (items, iter->data);
 		}
 		iter = g_list_previous (iter);
 	}
 	g_list_free (list);
+
+	vfolder_foreach (node_update_counters);
 	
 	debug1(DEBUG_UPDATE, "added %d new items", newCount);
 	
@@ -410,9 +436,63 @@ itemset_merge_items (itemSetPtr itemSet, GList *list, gboolean allowUpdates, gbo
 	return newCount;
 }
 
+gboolean
+itemset_check_item (itemSetPtr itemSet, itemPtr item)
+{
+	gboolean	result = TRUE;
+	GSList		*iter = itemSet->rules;
+
+	while (iter) {
+		rulePtr		rule = (rulePtr) iter->data;
+		ruleCheckFunc	func = rule->ruleInfo->checkFunc;
+		gboolean	ruleResult = FALSE;
+		
+		ruleResult = (*func) (rule, item);
+		result &= (rule->additive)?ruleResult:!ruleResult;
+		if (itemSet->anyMatch && result)
+			return TRUE;
+
+		iter = g_slist_next (iter);
+	}
+
+	return result;
+}
+
+gboolean
+itemset_has_item_id (itemSetPtr itemSet, gulong id)
+{
+	return (NULL != g_list_find (itemSet->ids, GUINT_TO_POINTER (id)));
+}
+
+void
+itemset_add_rule (itemSetPtr itemSet,
+                  const gchar *ruleId,
+                  const gchar *value,
+                  gboolean additive)
+{
+	rulePtr		rule;
+	
+	rule = rule_new (ruleId, value, additive);
+	if (rule)
+		itemSet->rules = g_slist_append (itemSet->rules, rule);
+	else
+		g_warning ("unknown search folder rule id: \"%s\"", ruleId);
+}
+
 void
 itemset_free (itemSetPtr itemSet)
 {
+	GSList		*rule;
+
+	if (!itemSet)
+		return;
+	
+	rule = itemSet->rules;
+	while (rule) {
+		rule_free (rule->data);
+		rule = g_slist_next (rule);
+	}
+	g_slist_free (itemSet->rules);
 	g_list_free (itemSet->ids);
 	g_free (itemSet);
 }
