@@ -1,7 +1,7 @@
 /**
  * @file cdf_channel.c CDF channel parsing
  *
- * Copyright (C) 2003-2009 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2003-2010 Lars Lindner <lars.lindner@gmail.com>
  * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,13 +23,15 @@
    things being case insensitive. Some people seem to make the tags
    capitalized, while others are like "Channel". */
 
+#include "cdf_channel.h"
+
 #include <sys/time.h>
 #include <string.h>
 #include <libxml/xmlmemory.h>
 #include <libxml/parser.h>
+
 #include "common.h"
 #include "feedlist.h"
-#include "cdf_channel.h"
 #include "cdf_item.h"
 #include "metadata.h"
 #include "xml.h"
@@ -49,9 +51,9 @@ static void parseCDFChannel(feedParserCtxtPtr ctxt, xmlNodePtr cur, CDFChannelPt
 		}
 
 		if((!xmlStrcasecmp(cur->name, BAD_CAST"logo"))) {
-			tmp = common_utf8_fix((gchar *)xmlGetProp(cur, BAD_CAST"HREF"));
+			tmp = (gchar *)xmlGetProp(cur, BAD_CAST"HREF");
 			if(tmp) {
-				tmp = common_utf8_fix((gchar *)xmlGetProp(cur, BAD_CAST"href"));
+				tmp = (gchar *)xmlGetProp(cur, BAD_CAST"href");
 				metadata_list_set (&ctxt->subscription->metadata, "imageUrl", tmp);
 				g_free(tmp);
 			}
@@ -72,7 +74,7 @@ static void parseCDFChannel(feedParserCtxtPtr ctxt, xmlNodePtr cur, CDFChannelPt
 			}
 
 		} else if(!xmlStrcasecmp(cur->name, BAD_CAST "title")) {
-			tmp = common_utf8_fix((gchar *)xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, TRUE));
+			tmp = (gchar *)xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, TRUE);
 			if(tmp) {
 				tmp = unhtmlize(tmp);
 				
@@ -82,7 +84,7 @@ static void parseCDFChannel(feedParserCtxtPtr ctxt, xmlNodePtr cur, CDFChannelPt
 			}
 			
 		} else if (!xmlStrcasecmp(cur->name, BAD_CAST "abstract")) {
-			tmp = common_utf8_fix ((gchar *)xmlNodeListGetString (cur->doc, cur->xmlChildrenNode, TRUE));
+			tmp = (gchar *)xmlNodeListGetString (cur->doc, cur->xmlChildrenNode, TRUE);
 			if (tmp) {
 				metadata_list_set (&ctxt->subscription->metadata, "description", tmp);
 				xmlFree (tmp);
@@ -92,7 +94,7 @@ static void parseCDFChannel(feedParserCtxtPtr ctxt, xmlNodePtr cur, CDFChannelPt
 			tmp = g_ascii_strdown((gchar *)cur->name, -1);
 			tmp2 = g_hash_table_lookup(channelHash, tmp);
 			if(tmp2) {
-				tmp3 = common_utf8_fix((gchar *)xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, TRUE));
+				tmp3 = (gchar *)xmlNodeListGetString(cur->doc, cur->xmlChildrenNode, TRUE);
 				if(tmp3) {
 					ctxt->subscription->metadata = metadata_list_append(ctxt->subscription->metadata, tmp2, tmp3);
 					g_free(tmp3);
@@ -181,9 +183,7 @@ feedHandlerPtr cdf_init_feed_handler(void) {
 	
 	/* prepare feed handler structure */
 	fhp->typeStr = "cdf";
-	fhp->icon = ICON_AVAILABLE;
 	fhp->feedParser	= cdf_parse;
 	fhp->checkFormat = cdf_format_check;
-	fhp->merge = TRUE;
 	return fhp;
 }
