@@ -1,7 +1,7 @@
 /**
  * @file pie_entry.c  Atom0.3 entry parsing 
  *
- * Copyright (C) 2003-2008 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2003-2009 Lars Lindner <lars.lindner@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -24,6 +24,7 @@
 #include <libxml/parser.h>
 
 #include "common.h"
+#include "date.h"
 #include "feed_parser.h"
 #include "pie_entry.h"
 #include "pie_feed.h"
@@ -82,7 +83,7 @@ itemPtr parseEntry(feedParserCtxtPtr ctxt, xmlNodePtr cur) {
 				g_free(tmp2);
 			} else {
 				/* 0.2 link : element content is the link, or non-alternate link in 0.3 */
-				if(NULL != (tmp = common_utf8_fix((gchar *)xmlNodeListGetString(ctxt->doc, cur->xmlChildrenNode, 1)))) {
+				if(NULL != (tmp = (gchar *)xmlNodeListGetString(ctxt->doc, cur->xmlChildrenNode, 1))) {
 					item_set_source(ctxt->item, tmp);
 					g_free(tmp);
 				}
@@ -98,19 +99,19 @@ itemPtr parseEntry(feedParserCtxtPtr ctxt, xmlNodePtr cur) {
 			ctxt->item->metadata = metadata_list_append(ctxt->item->metadata, "contributor", tmp);
 			g_free(tmp);
 		} else if(!xmlStrcmp(cur->name, BAD_CAST"id")) {
-			if(NULL != (tmp = common_utf8_fix((gchar *)xmlNodeListGetString(ctxt->doc, cur->xmlChildrenNode, 1)))) {
+			if(NULL != (tmp = (gchar *)xmlNodeListGetString(ctxt->doc, cur->xmlChildrenNode, 1))) {
 				item_set_id(ctxt->item, tmp);
 				g_free(tmp);
 			}
 		} else if(!xmlStrcmp(cur->name, BAD_CAST"issued")) {
 			/* FIXME: is <modified> or <issued> or <created> the time tag we want to display? */
- 			if(NULL != (tmp = common_utf8_fix((gchar *)xmlNodeListGetString(ctxt->doc, cur->xmlChildrenNode, 1)))) {
-				ctxt->item->time = parseISO8601Date(tmp);
+ 			if(NULL != (tmp = (gchar *)xmlNodeListGetString(ctxt->doc, cur->xmlChildrenNode, 1))) {
+				ctxt->item->time = date_parse_ISO8601 (tmp);
 				g_free(tmp);
 			}
 		} else if(!xmlStrcmp(cur->name, BAD_CAST"content")) {
 			/* <content> support */
-			if(NULL != (tmp = common_utf8_fix(pie_parse_content_construct(cur)))) {
+			if(NULL != (tmp = pie_parse_content_construct(cur))) {
 				item_set_description(ctxt->item, tmp);
 				g_free(tmp);
 			}
@@ -118,13 +119,13 @@ itemPtr parseEntry(feedParserCtxtPtr ctxt, xmlNodePtr cur) {
 			/* <summary> can be used for short text descriptions, if there is no
 			   <content> description we show the <summary> content */
 			if(!item_get_description(ctxt->item)) {
-				if(NULL != (tmp = common_utf8_fix(pie_parse_content_construct(cur)))) {
+				if(NULL != (tmp = pie_parse_content_construct(cur))) {
 					item_set_description(ctxt->item, tmp);
 					g_free(tmp);
 				}
 			}
 		} else if(!xmlStrcmp(cur->name, BAD_CAST"copyright")) {
- 			if(NULL != (tmp = common_utf8_fix((gchar *)xmlNodeListGetString(ctxt->doc, cur->xmlChildrenNode, 1)))) {
+ 			if(NULL != (tmp = (gchar *)xmlNodeListGetString(ctxt->doc, cur->xmlChildrenNode, 1))) {
 				ctxt->item->metadata = metadata_list_append(ctxt->item->metadata, "copyright", tmp);
 				g_free(tmp);
 			}
