@@ -1,7 +1,7 @@
 /**
- * @file ui_auth.c  authentication dialog
+ * @file auth_dialog.c  authentication dialog
  *
- * Copyright (C) 2007-2010 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2007-2011 Lars Lindner <lars.lindner@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -27,9 +27,6 @@
 #include "debug.h"
 #include "ui/liferea_dialog.h"
 
-static void auth_dialog_class_init	(AuthDialogClass *klass);
-static void auth_dialog_init		(AuthDialog *ad);
-
 #define AUTH_DIALOG_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), AUTH_DIALOG_TYPE, AuthDialogPrivate))
 
 struct AuthDialogPrivate {
@@ -45,34 +42,7 @@ struct AuthDialogPrivate {
 
 static GObjectClass *parent_class = NULL;
 
-GType
-auth_dialog_get_type (void) 
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0)) 
-	{
-		static const GTypeInfo our_info = 
-		{
-			sizeof (AuthDialogClass),
-			NULL, /* base_init */
-			NULL, /* base_finalize */
-			(GClassInitFunc) auth_dialog_class_init,
-			NULL,
-			NULL, /* class_data */
-			sizeof (AuthDialog),
-			0, /* n_preallocs */
-			(GInstanceInitFunc) auth_dialog_init,
-			NULL /* value_table */
-		};
-
-		type = g_type_register_static (G_TYPE_OBJECT,
-					       "AuthDialog",
-					       &our_info, 0);
-	}
-
-	return type;
-}
+G_DEFINE_TYPE (AuthDialog, auth_dialog, G_TYPE_OBJECT);
 
 static void
 auth_dialog_finalize (GObject *object)
@@ -121,7 +91,7 @@ on_authdialog_response (GtkDialog *dialog,
 }
 
 static void
-ui_auth_dialog_load (AuthDialog *ad,
+auth_dialog_load (AuthDialog *ad,
                      subscriptionPtr subscription,
                      gint flags)
 {
@@ -174,7 +144,7 @@ auth_dialog_init (AuthDialog *ad)
 	
 	ad->priv = AUTH_DIALOG_GET_PRIVATE (ad);
 	
-	ad->priv->dialog = authdialog = liferea_dialog_new ("auth.glade", "authdialog");
+	ad->priv->dialog = authdialog = liferea_dialog_new ("auth.ui", "authdialog");
 	ad->priv->username = liferea_dialog_lookup (authdialog, "usernameEntry");
 	ad->priv->password = liferea_dialog_lookup (authdialog, "passwordEntry");
 	
@@ -185,7 +155,7 @@ auth_dialog_init (AuthDialog *ad)
 
 
 AuthDialog *
-ui_auth_dialog_new (subscriptionPtr subscription, gint flags) 
+auth_dialog_new (subscriptionPtr subscription, gint flags) 
 {
 	AuthDialog *ad;
 	
@@ -195,6 +165,6 @@ ui_auth_dialog_new (subscriptionPtr subscription, gint flags)
 	}
 	
 	ad = AUTH_DIALOG (g_object_new (AUTH_DIALOG_TYPE, NULL));
-	ui_auth_dialog_load(ad, subscription, flags);
+	auth_dialog_load(ad, subscription, flags);
 	return ad;
 }
