@@ -1,7 +1,7 @@
 /**
  * @file liferea_htmlview.h  Liferea embedded HTML rendering
  *
- * Copyright (C) 2003-2008 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2003-2010 Lars Lindner <lars.lindner@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -45,7 +45,7 @@ struct LifereaHtmlView
 
 struct LifereaHtmlViewClass 
 {
-	GtkObjectClass parent_class;
+	GObjectClass parent_class;
 };
 
 GType liferea_htmlview_get_type	(void);
@@ -60,7 +60,7 @@ LifereaHtmlView * liferea_htmlview_new (gboolean forceInternalBrowsing);
 
 /**
  * Returns the rendering widget for a HTML view. Only
- * to be used by ui_mainwindow.c for widget reparenting.
+ * to be used by liferea_shell.c for widget reparenting.
  *
  * @param htmlview	the HTML view
  *
@@ -107,14 +107,10 @@ void liferea_htmlview_title_changed (LifereaHtmlView *htmlview, const gchar *tit
 
 void liferea_htmlview_location_changed (LifereaHtmlView *htmlview, const gchar *location);
 
-void liferea_htmlview_open (LifereaHtmlView *htmlview, const gchar *url);
-
-void liferea_htmlview_close (LifereaHtmlView *htmlview);
-
 /**
  * Launches the specified URL in the external browser or handles
  * a special URL by triggering HTML generation. Otherwise returns
- * TRUE to indicate the HTML widget should launch the link.
+ * FALSE to indicate the HTML widget should launch the link.
  *
  * To enforce a launching behaviour do use
  *
@@ -129,7 +125,7 @@ void liferea_htmlview_close (LifereaHtmlView *htmlview);
  * @param htmlview	the HTML view to use
  * @param url		URL to launch
  *
- * @returns TRUE if link is to be launched by browser widget
+ * @returns FALSE if link is to be launched by browser widget
  */
 gboolean liferea_htmlview_handle_URL (LifereaHtmlView *htmlview, const gchar *url);
 
@@ -173,26 +169,20 @@ gboolean liferea_htmlview_scroll (LifereaHtmlView *htmlview);
  *
  * @param htmlview	the html view
  * @param menu		the menu to fill
- * @param link		NULL or a valid URL string if this is 
- *			to be a link context menu (to be free'd
- *			using g_free)
+ * @param linkUri	NULL or a valid URL string if this is 
+ *			to be a link context menu
+ * @param imageUri	NULL or a valid image URL if this is 
+ * 			to be an image context menu
  */
-void liferea_htmlview_prepare_context_menu (LifereaHtmlView *htmlview, GtkMenu *menu, gchar *link);
+void liferea_htmlview_prepare_context_menu (LifereaHtmlView *htmlview, GtkMenu *menu, const gchar *linkUri, const gchar *imageUri);
 
 /**
- * To be called when HTML view needs to update the proxy settings
- * of the rendering widget implementation.
- */
-void liferea_htmlview_update_proxy (void);
-
-/**
- * To be called when HTML view needs to update the online state
+ * To be called when HTML view needs to change the text size
  * of the rendering widget implementation.
  *
- * @param online	the new online state
+ * @param htmlview	the html view
+ * @param in		TRUE if zoom is to be increased
  */
-void liferea_htmlview_set_online (gboolean online);
-
 void liferea_htmlview_do_zoom (LifereaHtmlView *htmlview, gboolean in);
 
 G_END_DECLS
@@ -208,14 +198,18 @@ typedef struct htmlviewImpl {
 	void		(*launch)		(GtkWidget *widget, const gchar *url);
 	gfloat		(*zoomLevelGet)		(GtkWidget *widget);
 	void		(*zoomLevelSet)		(GtkWidget *widget, gfloat zoom);
+	gboolean	(*hasSelection)		(GtkWidget *widget);
+	void		(*copySelection)	(GtkWidget *widget);
 	gboolean	(*scrollPagedown)	(GtkWidget *widget);
 	void		(*setProxy)		(const gchar *hostname, guint port, const gchar *username, const gchar *password);
 	void		(*setOffLine)		(gboolean offline);
 } *htmlviewImplPtr;
 
+extern htmlviewImplPtr htmlview_get_impl(void);
+
 /* Use this macro to declare a html rendering support implementation. */
 #define DECLARE_HTMLVIEW_IMPL(impl) \
-        htmlviewImplPtr htmlview_get_impl() { \
+        htmlviewImplPtr htmlview_get_impl(void) { \
                 return &impl; \
         }
 
