@@ -1,7 +1,7 @@
 /**
  * @file search-folder-dialog.c  Search folder properties dialog
  *
- * Copyright (C) 2007-2008 Lars Lindner <lars.lindner@gmail.com>
+ * Copyright (C) 2007-2011 Lars Lindner <lars.lindner@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,15 +23,12 @@
 #include "feedlist.h"
 #include "itemlist.h"
 #include "vfolder.h"
+#include "ui/itemview.h"
 #include "ui/liferea_dialog.h"
 #include "ui/liferea_shell.h"
 #include "ui/rule_editor.h"
-#include "ui/ui_itemlist.h"
 #include "ui/ui_node.h"
 
-static void search_folder_dialog_class_init	(SearchFolderDialogClass *klass);
-static void search_folder_dialog_init		(SearchFolderDialog *ld);
-
 #define SEARCH_FOLDER_DIALOG_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), SEARCH_FOLDER_DIALOG_TYPE, SearchFolderDialogPrivate))
 
 struct SearchFolderDialogPrivate {
@@ -43,33 +40,7 @@ struct SearchFolderDialogPrivate {
 
 static GObjectClass *parent_class = NULL;
 
-GType
-search_folder_dialog_get_type (void) 
-{
-	static GType type = 0;
-
-	if (G_UNLIKELY (type == 0)) 
-	{
-		static const GTypeInfo our_info = 
-		{
-			sizeof (SearchFolderDialogClass),
-			NULL, /* base_init */
-			NULL, /* base_finalize */
-			(GClassInitFunc) search_folder_dialog_class_init,
-			NULL,
-			NULL, /* class_data */
-			sizeof (SearchFolderDialog),
-			0, /* n_preallocs */
-			(GInstanceInitFunc) search_folder_dialog_init
-		};
-
-		type = g_type_register_static (G_TYPE_OBJECT,
-					       "SearchFolderDialog",
-					       &our_info, 0);
-	}
-
-	return type;
-}
+G_DEFINE_TYPE (SearchFolderDialog, search_folder_dialog, G_TYPE_OBJECT);
 
 static void
 search_folder_dialog_finalize (GObject *object)
@@ -107,12 +78,12 @@ on_propdialog_response (GtkDialog *dialog, gint response_id, gpointer user_data)
 	if (response_id == GTK_RESPONSE_OK) {	
 		/* save new search folder settings */
 		node_set_title (sfd->priv->node, gtk_entry_get_text (GTK_ENTRY (sfd->priv->nameEntry)));
-		rule_editor_save (sfd->priv->re, sfd->priv->vfolder);
-		sfd->priv->vfolder->anyMatch = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (GTK_WIDGET (dialog), "anyRuleRadioBtn")));
+		rule_editor_save (sfd->priv->re, sfd->priv->vfolder->itemset);
+		sfd->priv->vfolder->itemset->anyMatch = gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (GTK_WIDGET (dialog), "anyRuleRadioBtn")));
 
 		/* update search folder */
-		ui_itemlist_clear ();
-		vfolder_refresh (sfd->priv->vfolder);
+		itemview_clear ();
+		vfolder_reset (sfd->priv->vfolder);
 		itemlist_unload (FALSE);
 		
 		/* If we are finished editing a new search folder add it to the feed list */
@@ -120,10 +91,6 @@ on_propdialog_response (GtkDialog *dialog, gint response_id, gpointer user_data)
 			feedlist_node_added (sfd->priv->node);
 			
 		ui_node_update (sfd->priv->node->id);
-	} else if (response_id == GTK_RESPONSE_CANCEL) {
-		/* Only destroy temporary nodes */
-		if (!sfd->priv->node->parent)
-			node_free(sfd->priv->node);
 	}
 	
 	gtk_widget_destroy (GTK_WIDGET (dialog));
@@ -145,9 +112,9 @@ search_folder_dialog_new (nodePtr node)
 	SearchFolderDialog	*sfd;
 	
 	sfd = SEARCH_FOLDER_DIALOG (g_object_new (SEARCH_FOLDER_DIALOG_TYPE, NULL));
-	sfd->priv->re = rule_editor_new ((vfolderPtr)node->data);
 	sfd->priv->node = node;
 	sfd->priv->vfolder = (vfolderPtr)node->data;
+	sfd->priv->re = rule_editor_new (sfd->priv->vfolder->itemset);
 	
 	/* Create the dialog */
 	dialog = liferea_dialog_new (NULL, "vfolderdialog");
@@ -157,7 +124,7 @@ search_folder_dialog_new (nodePtr node)
 	gtk_entry_set_text (GTK_ENTRY (sfd->priv->nameEntry), node_get_title (node));
 	
 	/* Set up rule match type */
-	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (dialog, sfd->priv->vfolder->anyMatch?"anyRuleRadioBtn":"allRuleRadioBtn")), TRUE);
+	gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (liferea_dialog_lookup (dialog, sfd->priv->vfolder->itemset->anyMatch?"anyRuleRadioBtn":"allRuleRadioBtn")), TRUE);
 	
 	/* Set up rule list vbox */
 	gtk_container_add (GTK_CONTAINER (liferea_dialog_lookup (dialog, "ruleview_vfolder_dialog")), rule_editor_get_widget (sfd->priv->re));
